pub struct DeserializeDefinitionShape {
pub id: ShapeId,
pub type_name: TypeName,
pub description: Option<&'static str>,
pub kind: DeserializeDefinitionKind,
}Expand description
A named type definition in a deserialization shape graph.
Fields
id: ShapeIdThe stable id of this definition inside its graph.
type_name: TypeNameThe Rust and Serde names for this definition.
description: Option<&'static str>User-facing documentation for this definition, if available.
kind: DeserializeDefinitionKindThe definition body.