pub struct DeserializeFieldShape {
pub member: FieldMember,
pub name: &'static str,
pub aliases: Vec<&'static str>,
pub description: Option<&'static str>,
pub wire_shape: FieldWireShape,
pub default: DefaultShape,
}Expand description
Field-level deserialization metadata.
Fields
member: FieldMemberThe original Rust field member.
name: &'static strThe primary Serde deserialize name.
aliases: Vec<&'static str>All accepted Serde deserialize names, including the primary name.
description: Option<&'static str>User-facing documentation for this field, if available.
wire_shape: FieldWireShapeHow this field contributes to the deserialized wire shape.
default: DefaultShapeThe default used if this field is missing.