pub struct SerializeDefinitionShape {
pub id: ShapeId,
pub type_name: TypeName,
pub description: Option<&'static str>,
pub kind: SerializeDefinitionKind,
}Expand description
A named type definition in a serialization shape graph.
Fields
id: ShapeIdThe stable id of this definition inside its graph.
type_name: TypeNameThe Rust and Serde names for this definition.
description: Option<&'static str>User-facing documentation for this definition, if available.
kind: SerializeDefinitionKindThe definition body.