pub struct ShapeContext { /* private fields */ }Expand description
Accumulates named definitions while a shape graph is built.
Implementations
Sourceimpl ShapeContext
impl ShapeContext
Sourcepub fn define_named_type<F>(
&mut self,
type_name: TypeName,
build: F,
) -> ShapeRefwhere
F: FnOnce(&mut Self) -> DefinitionKind,
pub fn define_named_type<F>(
&mut self,
type_name: TypeName,
build: F,
) -> ShapeRefwhere
F: FnOnce(&mut Self) -> DefinitionKind,
Define a named type once and return a reference to its definition.