pub struct UnionShape { /* private fields */ }Expand description
The normalized alternatives contained by ShapeRef::Union.
A union always contains at least two distinct alternatives in canonical order. Use
ShapeRef::union or ShapeRef::try_union to construct one. Alternatives may overlap; a
union means that any alternative is possible, not that exactly one alternative must match.
Implementations
Sourceimpl UnionShape
impl UnionShape
Sourcepub fn alternatives(&self) -> &[ShapeRef]
pub fn alternatives(&self) -> &[ShapeRef]
Returns the canonical union alternatives.