pub struct VariantShape {
pub rust_name: &'static str,
pub deserialize_name: &'static str,
pub deserialize_aliases: Vec<&'static str>,
pub style: FieldsStyle,
pub fields: Vec<FieldShape>,
pub skip_deserializing: bool,
pub custom_deserializer: bool,
pub other: bool,
pub untagged: bool,
}Expand description
Variant-level shape metadata.
Fields
rust_name: &'static strThe original Rust variant name.
deserialize_name: &'static strThe primary Serde deserialize name.
deserialize_aliases: Vec<&'static str>All accepted Serde deserialize names, including the primary name.
style: FieldsStyleThe variant field style.
fields: Vec<FieldShape>The variant fields, if their input shape can be inferred.
skip_deserializing: boolWhether Serde skips this variant during deserialization.
custom_deserializer: boolWhether this variant uses a custom deserializer.
other: boolWhether this is a Serde other catch-all variant.
untagged: boolWhether this variant is individually marked untagged.