#[non_exhaustive]pub enum FieldWireShape {
Omitted,
Value(ShapeRef),
Flatten(ShapeRef),
Inline(ShapeRef),
}Expand description
How a field contributes to the wire representation in one Serde direction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Omitted
The field emits or accepts no value in this direction.
Value(ShapeRef)
The field appears as a regular value at its Serde position.
Flatten(ShapeRef)
The field is flattened into the containing map.
Inline(ShapeRef)
The field is serialized or deserialized directly at the containing type’s position.
Implementations